@@ -9,7 +9,6 @@ from json import loads
 import requests
 from bs4 import BeautifulSoup
 
-
 def doomsday_clock(year):
     dc_url = "https://ja.wikipedia.org/wiki/%E4%B8%96%E7%95%8C%E7%B5%82%E6%9C%AB%E6%99%82%E8%A8%88"
     resp = requests.get(dc_url)
@@ -89,4 +88,16 @@ def ppl(code=13):
     6時間ごと，7つ
     """
     d = get_wf_json(code)
-    return [int(x) for x in d[0]["timeSeries"][1]["areas"][0]["pops"]]
\ No newline at end of file
+    return [int(x) for x in d[0]["timeSeries"][1]["areas"][0]["pops"]]
+
+
+def get_eq_info():
+    """
+    api.p2pquake.netから，日本で発生した直近の地震の情報を取り出す
+    戻り値は辞書
+    """
+    # 地震の情報を読み込む
+    url = "https://api.p2pquake.net/v2/jma/quake?limit=1"
+    r = requests.get(url)
+    ql = loads(r.text)
+    return ql[0]["earthquake"]["hypocenter"]
\ No newline at end of file
